@@ -1,7 +1,7 @@
 package Data::Sah::Coerce::perl::str::str_to_cryptocurrency_safename;
 
 our $DATE = '2018-06-04'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
@@ -30,7 +30,7 @@ sub coerce {
         "",
         "do { my \$cat = CryptoCurrency::Catalog->new; ",
         "my \$rec; eval { \$rec = \$cat->by_code($dt) }; if (\$@) { eval { \$rec = \$cat->by_name($dt) } } if (\$@) { eval { \$rec = \$cat->by_safename($dt) } } ",
-        "if (\$@) { ['Unknown cryptocurrency code/name/safename'] } else { [undef, \$rec->{safename}] } ",
+        "if (\$@) { ['Unknown cryptocurrency code/name/safename: ' . $dt] } else { [undef, \$rec->{safename}] } ",
         "}",
     );
 
@@ -52,7 +52,7 @@ Data::Sah::Coerce::perl::str::str_to_cryptocurrency_safename - Coerce string con
 
 =head1 VERSION
 
-This document describes version 0.002 of Data::Sah::Coerce::perl::str::str_to_cryptocurrency_safename (from Perl distribution Data-Sah-Coerce-perl-str-str_to_cryptocurrency_safename), released on 2018-06-04.
+This document describes version 0.003 of Data::Sah::Coerce::perl::str::str_to_cryptocurrency_safename (from Perl distribution Data-Sah-Coerce-perl-str-str_to_cryptocurrency_safename), released on 2018-06-04.
 
 =head1 DESCRIPTION
 
